Class: Flipper::Api::Action

Inherits:
Object
  • Object
show all
Extended by:
Forwardable
Defined in:
lib/flipper/api/action.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(flipper, request) ⇒ Action

Returns a new instance of Action.



40
41
42
43
44
# File 'lib/flipper/api/action.rb', line 40

def initialize(flipper, request)
  @flipper, @request = flipper, request
  @code = 200
  @headers = {"Content-Type" => Api::CONTENT_TYPE }
end

Instance Attribute Details

#flipper ⇒ Object (readonly)

Public: The instance of the Flipper::DSL the middleware was initialized with.



32
33
34
# File 'lib/flipper/api/action.rb', line 32

def flipper
  @flipper
end

#request ⇒ Object (readonly)

Public: The Rack::Request to provide a response for.



35
36
37
# File 'lib/flipper/api/action.rb', line 35

def request
  @request
end

Class Method Details

.regex ⇒ Object

Internal: The regex that matches which routes this action will work for.



26
27
28
# File 'lib/flipper/api/action.rb', line 26

def self.regex
  @regex || raise("#{name}.route is not set")
end

.route(regex) ⇒ Object

Public: Call this in subclasses so the action knows its route.

regex - The Regexp that this action should run for.

Returns nothing.



11
12
13
# File 'lib/flipper/api/action.rb', line 11

def self.route(regex)
  @regex = regex
end

.run(flipper, request) ⇒ Object

Internal: Initializes and runs an action for a given request.

flipper - The Flipper::DSL instance. request - The Rack::Request that was sent.

Returns result of Action#run.



21
22
23
# File 'lib/flipper/api/action.rb', line 21

def self.run(flipper, request)
  new(flipper, request).run
end

Instance Method Details

#halt(response) ⇒ Object

Public: Call this with a response to immediately stop the current action and respond however you want.

response - The response you would like to return.



76
77
78
# File 'lib/flipper/api/action.rb', line 76

def halt(response)
  throw :halt, response
end

#header(name, value) ⇒ Object

Public: Set a header.

name - The String name of the header. value - The value of the header.



98
99
100
# File 'lib/flipper/api/action.rb', line 98

def header(name, value)
  @headers[name] = value
end

#json_response(object, status = 200) ⇒ Object



80
81
82
83
84
85
# File 'lib/flipper/api/action.rb', line 80

def json_response(object, status = 200)
  header 'Content-Type', Api::CONTENT_TYPE
  status(status)
  body = JSON.dump(object)
  halt [@code, @headers, [body]]
end

#run ⇒ Object

Public: Runs the request method for the provided request.

Returns whatever the request method returns in the action.



49
50
51
52
53
54
55
# File 'lib/flipper/api/action.rb', line 49

def run
  if respond_to?(request_method_name)
    catch(:halt) { send(request_method_name) }
  else
    raise Api::RequestMethodNotSupported, "#{self.class} does not support request method #{request_method_name.inspect}"
  end
end

#run_other_action(action_class) ⇒ Object

Public: Runs another action from within the request method of a different action.

action_class - The class of the other action to run.

Examples

run_other_action Home
# => result of running Home action

Returns result of other action.



68
69
70
# File 'lib/flipper/api/action.rb', line 68

def run_other_action(action_class)
  action_class.new(flipper, request).run
end

#status(code) ⇒ Object

Public: Set the status code for the response.

code - The Integer code you would like the response to return.



90
91
92
# File 'lib/flipper/api/action.rb', line 90

def status(code)
  @code = code.to_i
end